@@ -16,7 +16,7 @@ function(accounts_id  = getOption("rfacebookstat.accounts_id"),
     }
   }
   
-  if ( class(access_token) == "fb_access_token" ) {
+  if ( inherits(access_token, "fb_access_token") ) {
     
     access_token <- access_token$access_token
     
